@@ -43,7 +43,7 @@ public:
 
     BitCount32 size() const override;
 
-    qint64 readData(Okteta::AbstractByteArrayModel* input, Okteta::Address address,
+    qint64 readData(const Okteta::AbstractByteArrayModel* input, Okteta::Address address,
                     BitCount64 bitsRemaining, quint8* bitOffset) override;
     bool setData(const QVariant& value, Okteta::AbstractByteArrayModel* out,
                  Okteta::Address address, BitCount64 bitsRemaining, quint8 bitOffset) override;
@@ -78,6 +78,7 @@ public:
 private:
     QScriptClass* scriptClass(ScriptHandlerInfo* handlerInfo) const override;
     QString typeNameImpl() const override;
+    QString valueStringImpl() const override;
 
 private:
     QScopedPointer<AbstractArrayData> mData;
